<?xml version="1.0"?>
<!--
    inline.mod.xsl - inline elements like "@emph".
	$Id: inline.mod.xsl,v 1.9 2005/01/02 14:41:26 Bronger Exp $	

    Copyright © 2004, 2005 Torsten Bronger <bronger@physik.rwth-aachen.de>.

    This file is part of texi2latex.

    texi2latex is free software; you can redistribute it and/or modify it under
    the terms of the GNU General Public License as published by the Free
    Software Foundation; either version 2 of the License, or (at your option)
    any later version.

    texi2latex is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
    more details.

    You should have received a copy of the GNU General Public License along
    with texi2latex; if not, write to the Free Software Foundation, Inc., 59
    Temple Place, Suite 330, Boston, MA 02111-1307 USA
-->

<xsl:stylesheet version="1.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<!-- The following commands are called "indicating" in the Texinfo manual.
     Very straightforward I suppose. -->

<xsl:template match="code">
  <xsl:text>\mbox{\ttfamily </xsl:text>
  <xsl:apply-templates/>
  <xsl:text>}</xsl:text>
</xsl:template>

<xsl:template match="kbd">
  <xsl:text>\mbox{\ttfamily </xsl:text>
  <xsl:apply-templates/>
  <xsl:text>}</xsl:text>
</xsl:template>

<!-- FixMe: This one should optionally make use of the keystroke package. -->

<xsl:template match="key">
  <xsl:text>\fbox{\sffamily </xsl:text>
  <xsl:apply-templates/>
  <xsl:text>}</xsl:text>
</xsl:template>

<xsl:template match="samp">
  <xsl:text>&gt;&gt;\mbox{\sffamily </xsl:text>
  <xsl:apply-templates/>
  <xsl:text>}&lt;&lt;</xsl:text>
</xsl:template>

<xsl:template match="verb">
  <xsl:text>\mbox{\ttfamily </xsl:text>
  <xsl:apply-templates/>
  <xsl:text>}</xsl:text>
</xsl:template>

<xsl:template match="var">
  <xsl:text>\mbox{\slshape </xsl:text>
  <xsl:apply-templates/>
  <xsl:text>}</xsl:text>
</xsl:template>

<xsl:template match="env">
  <xsl:text>\mbox{\MakeUppercase{</xsl:text>
  <xsl:apply-templates/>
  <xsl:text>}}</xsl:text>
</xsl:template>

<xsl:template match="file">
  <xsl:text>{\hyphenrules{nohyphenation}\ttfamily </xsl:text>
  <xsl:apply-templates/>
  <xsl:text>}</xsl:text>
</xsl:template>

<xsl:template match="file/text()">
  <xsl:value-of select="$start-delimiter"/>
  <xsl:call-template name="insert-breakpoints">
    <!-- "/\" for POSIX and Windows. -->
    <xsl:with-param name="break-after" select="'/\'"/>
    <xsl:with-param name="string" select="."/>
  </xsl:call-template>
  <xsl:value-of select="$end-delimiter"/>
</xsl:template>

<xsl:template match="command">
  <xsl:text>\mbox{\ttfamily </xsl:text>
  <xsl:apply-templates/>
  <xsl:text>}</xsl:text>
</xsl:template>

<xsl:template match="option">
  <xsl:text>\mbox{\ttfamily </xsl:text>
  <xsl:apply-templates/>
  <xsl:text>}</xsl:text>
</xsl:template>

<xsl:template match="dfn">
  <xsl:text>\mbox{\ttfamily </xsl:text>
  <xsl:apply-templates/>
  <xsl:text>}</xsl:text>
</xsl:template>

<xsl:template match="cite">
  <xsl:text>\textit{</xsl:text>
  <xsl:apply-templates/>
  <xsl:text>}</xsl:text>
</xsl:template>

<!-- For acronyms, every occurence of acronymdesc is processed.  Maybe it would
     be better to limit that to the first one (one one specific acronym). -->

<xsl:template match="acronym">
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="acronymword">
  <xsl:text>\mbox{\sffamily </xsl:text>
  <xsl:apply-templates/>
  <xsl:text>}</xsl:text>
</xsl:template>

<xsl:template match="acronymdesc">
  <xsl:text>\footnote{</xsl:text>
  <xsl:apply-templates/>
  <xsl:text>}</xsl:text>
</xsl:template>


<!-- The following commands are called "emphasizing" in the Texinfo
     manual. -->

<xsl:template match="emph">
  <xsl:text>\emph{</xsl:text>
  <xsl:apply-templates/>
  <xsl:text>}</xsl:text>
</xsl:template>

<xsl:template match="strong">
  <xsl:text>\textbf{</xsl:text>
  <xsl:apply-templates/>
  <xsl:text>}</xsl:text>
</xsl:template>

<xsl:template match="sc">
  <xsl:text>\textsc{</xsl:text>
  <xsl:apply-templates/>
  <xsl:text>}</xsl:text>
</xsl:template>

<xsl:template match="i">
  <xsl:text>\textit{</xsl:text>
  <xsl:apply-templates/>
  <xsl:text>}</xsl:text>
</xsl:template>

<xsl:template match="b">
  <xsl:text>\textbf{</xsl:text>
  <xsl:apply-templates/>
  <xsl:text>}</xsl:text>
</xsl:template>

<xsl:template match="t">
  <xsl:text>\texttt{</xsl:text>
  <xsl:apply-templates/>
  <xsl:text>}</xsl:text>
</xsl:template>

<xsl:template match="r">
  <xsl:text>\textrm{</xsl:text>
  <xsl:apply-templates/>
  <xsl:text>}</xsl:text>
</xsl:template>

<xsl:template match="dmn">
  <xsl:text>\,</xsl:text>
  <xsl:text>\textrm{</xsl:text>
  <xsl:apply-templates/>
  <xsl:text>}</xsl:text>
</xsl:template>

<xsl:template match="math">
  <xsl:text>$</xsl:text>
  <xsl:value-of select="."/>
  <xsl:text>$</xsl:text>
</xsl:template>

<xsl:template match="footnote">
  <xsl:text>\footnote{</xsl:text>
  <xsl:apply-templates select="para/node()"/>  <!-- FixMe: Multiple <para>s are not dealt with -->
  <xsl:text>}</xsl:text>
</xsl:template>

<!-- Logos -->

<xsl:template match="logo">
  <xsl:variable name="name" select="normalize-space(.)"/>
  <xsl:choose>
    <xsl:when test="$name = 'LaTeX'">
      <xsl:text>\LaTeX{}</xsl:text>
    </xsl:when>
    <xsl:when test="$name = 'TeX'">
      <xsl:text>\TeX{}</xsl:text>
    </xsl:when>
    <xsl:otherwise>
      <xsl:value-of select="$name"/>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

</xsl:stylesheet>
